@@ -82,13 +82,6 @@ get_provider_name (GoaProvider *_provider,
   return g_strdup (_("Windows Live"));
 }
 
-static GIcon *
-get_provider_icon (GoaProvider *provider,
-                   GoaObject   *object)
-{
-  return g_themed_icon_new_with_default_fallbacks ("goa-account-msn");
-}
-
 static const gchar *
 get_authorization_uri (GoaOAuth2Provider *provider)
 {
@@ -270,6 +263,7 @@ build_object (GoaProvider         *provider,
               GoaObjectSkeleton   *object,
               GKeyFile            *key_file,
               const gchar         *group,
+              GDBusConnection     *connection,
               gboolean             just_added,
               GError             **error)
 {
@@ -287,6 +281,7 @@ build_object (GoaProvider         *provider,
                                                                               object,
                                                                               key_file,
                                                                               group,
+                                                                              connection,
                                                                               just_added,
                                                                               error))
     goto out;
@@ -414,7 +409,6 @@ goa_windows_live_provider_class_init (GoaWindowsLiveProviderClass *klass)
   provider_class = GOA_PROVIDER_CLASS (klass);
   provider_class->get_provider_type          = get_provider_type;
   provider_class->get_provider_name          = get_provider_name;
-  provider_class->get_provider_icon          = get_provider_icon;
   provider_class->build_object               = build_object;
   provider_class->show_account               = show_account;
   provider_class->get_credentials_generation = get_credentials_generation;
